import{d as l,H as r,b as n,er as o,e as a,bu as c,ez as d,ew as _,eA as i,eu as u,v as f}from"./registerWidgets.1e9167ab.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="035df00e-b657-4597-8d75-b5221784ee9b",e._sentryDebugIdIdentifier="sentry-dbid-035df00e-b657-4597-8d75-b5221784ee9b")}catch{}})();const b={key:0,class:"p-steps p-component"},m={class:"p-steps-list"},y={class:"p-menuitem-link"},g={class:"p-steps-number"},I=l({__name:"Steps",props:{stepsInfo:{type:Object,default:null}},setup(e){const s=e,p=r(()=>s.stepsInfo?Array(s.stepsInfo.total).fill(null).map(()=>({label:"",to:""})):[]);return(h,v)=>e.stepsInfo?(n(),o("nav",b,[a("ol",m,[(n(!0),o(c,null,d(p.value,(k,t)=>(n(),o("li",{key:t,class:_(["p-steps-item",{"p-highlight":t+1===e.stepsInfo.current}])},[a("span",y,[a("span",g,i(t+1),1)])],2))),128))])])):u("",!0)}});const D=f(I,[["__scopeId","data-v-c6d9488a"]]);export{D as S};
//# sourceMappingURL=Steps.64a40e70.js.map
