import{ab as i,U as t,Q as r,f as p}from"./registerWidgets.1e9167ab.js";import{B as c,b as l}from"./Title.d1f45d59.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="11c7fee4-7c9f-41c8-9b90-ebd4a4aaaaf6",e._sentryDebugIdIdentifier="sentry-dbid-11c7fee4-7c9f-41c8-9b90-ebd4a4aaaaf6")}catch{}})();const b=()=>t(t({},r(l(),["component"])),{ellipsis:{type:[Boolean,Object],default:void 0}}),n=(e,s)=>{let{slots:o,attrs:d}=s;const{ellipsis:a}=e;i();const f=t(t(t({},e),{ellipsis:a&&typeof a=="object"?r(a,["expandable","rows"]):a,component:"span"}),d);return p(c,f,o)};n.displayName="ATypographyText";n.inheritAttrs=!1;n.props=b();const g=n;export{g as A};
//# sourceMappingURL=Text.c8d7b4c0.js.map
