[data-v-22f08b8b]:root{--main-font-family: DM Sans, sans-serif}[data-v-22f08b8b]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown[data-v-22f08b8b]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-22f08b8b]{background-color:#fff;padding:10px}.buttons[data-v-22f08b8b]{display:flex;flex-direction:row;width:100%;justify-content:space-between}.main-text[data-v-22f08b8b]{text-align:center;height:50px;margin-bottom:1rem}.fields[data-v-22f08b8b]{display:flex;flex-direction:column;align-items:stretch;margin-bottom:1rem;gap:1rem}.fields .field[data-v-22f08b8b]{display:flex;flex-direction:column;align-items:flex-start;gap:.5rem}.separator[data-v-22f08b8b]{height:1px;width:100%;background-color:#e9ecef;margin:20px 0 30px}.cancel[data-v-22f08b8b]{cursor:pointer;display:flex;flex-direction:row;justify-content:center;align-items:center;padding:8px 20px;gap:10px;border:none;border-radius:4px;font-family:DM Sans,sans-serif;text-decoration:none;color:#d14056;border:1px solid #d14056;background:transparent}.cancel[data-v-22f08b8b]:hover{background:#f3f8ff}.cancel[data-v-22f08b8b]:active,.cancel active[data-v-22f08b8b]{background:#d6e4f7}.create[data-v-22f08b8b]{cursor:pointer;display:flex;flex-direction:row;justify-content:center;align-items:center;padding:8px 20px;gap:10px;border:none;border-radius:4px;font-family:DM Sans,sans-serif;text-decoration:none;background:#d14056;color:#fff;box-shadow:0 2px 4px #00000026}.create[data-v-22f08b8b]:hover{background:#e55b70;box-shadow:0 4px 12px #00000026}.create[data-v-22f08b8b]:active,.create active[data-v-22f08b8b]{background:#e55b70;box-shadow:inset 0 4px 4px #0000000f}.create[data-v-22f08b8b]:only-child{margin:0 auto}.ws-name[data-v-22f08b8b]{align-self:stretch;background:white;border:1px solid #dbdee4;border-radius:4px;padding:8px 12px;font-size:14px;font-weight:400;line-height:16px;letter-spacing:0em;text-align:left}
