import"./registerWidgets.1e9167ab.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="df78a5ec-f4d2-479a-ac22-ede89cc1c6af",a._sentryDebugIdIdentifier="sentry-dbid-df78a5ec-f4d2-479a-ac22-ede89cc1c6af")}catch{}})();class r{static get(e){try{const t=localStorage.getItem(e);return t&&JSON.parse(t)}catch{return null}}static set(e,t){localStorage.setItem(e,JSON.stringify(t))}static pop(e){const t=r.get(e);return r.remove(e),t}static remove(e){localStorage.removeItem(e)}}export{r as S};
//# sourceMappingURL=storage.84fcb572.js.map
