import{f as p,bt as le,U as f,de as xe,dX as We,aD as Ue,B as Ve,d as re,bb as Fe,G as Se,J as ne,r as oe,o as Oe,O as Ee,cG as Ke,R as U,b8 as Q,i as Xe,N as Te,dY as we,H as X,a0 as qe,x as Y,a3 as fe,a_ as Ge,ab as ie,aE as Je,bx as Z,Q as $e,bu as ge,cc as Qe,S as Ye,bw as ee,c7 as Ze,bW as et,dZ as tt}from"./registerWidgets.1e9167ab.js";import{T as ye}from"./transButton.755e702e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="4cf8bca4-e215-4032-8a52-aa8fe1553d7f",e._sentryDebugIdIdentifier="sentry-dbid-4cf8bca4-e215-4032-8a52-aa8fe1553d7f")}catch{}})();var nt={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M832 64H296c-4.4 0-8 3.6-8 8v56c0 4.4 3.6 8 8 8h496v688c0 4.4 3.6 8 8 8h56c4.4 0 8-3.6 8-8V96c0-17.7-14.3-32-32-32zM704 192H192c-17.7 0-32 14.3-32 32v530.7c0 8.5 3.4 16.6 9.4 22.6l173.3 173.3c2.2 2.2 4.7 4 7.4 5.5v1.9h4.2c3.5 1.3 7.2 2 11 2H704c17.7 0 32-14.3 32-32V224c0-17.7-14.3-32-32-32zM350 856.2L263.9 770H350v86.2zM664 888H414V746c0-22.1-17.9-40-40-40H232V264h432v624z"}}]},name:"copy",theme:"outlined"};const ot=nt;function me(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},o=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(o=o.concat(Object.getOwnPropertySymbols(n).filter(function(i){return Object.getOwnPropertyDescriptor(n,i).enumerable}))),o.forEach(function(i){it(e,i,n[i])})}return e}function it(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var ae=function(t,n){var o=me({},t,n.attrs);return p(le,me({},o,{icon:ot}),null)};ae.displayName="CopyOutlined";ae.inheritAttrs=!1;const lt=ae;var rt={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M257.7 752c2 0 4-.2 6-.5L431.9 722c2-.4 3.9-1.3 5.3-2.8l423.9-423.9a9.96 9.96 0 000-14.1L694.9 114.9c-1.9-1.9-4.4-2.9-7.1-2.9s-5.2 1-7.1 2.9L256.8 538.8c-1.5 1.5-2.4 3.3-2.8 5.3l-29.5 168.2a33.5 33.5 0 009.4 29.8c6.6 6.4 14.9 9.9 23.8 9.9zm67.4-174.4L687.8 215l73.3 73.3-362.7 362.6-88.9 15.7 15.6-89zM880 836H144c-17.7 0-32 14.3-32 32v36c0 4.4 3.6 8 8 8h784c4.4 0 8-3.6 8-8v-36c0-17.7-14.3-32-32-32z"}}]},name:"edit",theme:"outlined"};const at=rt;function be(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},o=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(o=o.concat(Object.getOwnPropertySymbols(n).filter(function(i){return Object.getOwnPropertyDescriptor(n,i).enumerable}))),o.forEach(function(i){st(e,i,n[i])})}return e}function st(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var se=function(t,n){var o=be({},t,n.attrs);return p(le,be({},o,{icon:at}),null)};se.displayName="EditOutlined";se.inheritAttrs=!1;const ct=se;var dt={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M864 170h-60c-4.4 0-8 3.6-8 8v518H310v-73c0-6.7-7.8-10.5-13-6.3l-141.9 112a8 8 0 000 12.6l141.9 112c5.3 4.2 13 .4 13-6.3v-75h498c35.3 0 64-28.7 64-64V178c0-4.4-3.6-8-8-8z"}}]},name:"enter",theme:"outlined"};const ut=dt;function he(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},o=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(o=o.concat(Object.getOwnPropertySymbols(n).filter(function(i){return Object.getOwnPropertyDescriptor(n,i).enumerable}))),o.forEach(function(i){pt(e,i,n[i])})}return e}function pt(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var ce=function(t,n){var o=he({},t,n.attrs);return p(le,he({},o,{icon:ut}),null)};ce.displayName="EnterOutlined";ce.inheritAttrs=!1;const ft=ce,gt=(e,t,n,o)=>{const{sizeMarginHeadingVerticalEnd:i,fontWeightStrong:c}=o;return{marginBottom:i,color:n,fontWeight:c,fontSize:e,lineHeight:t}},yt=e=>{const t=[1,2,3,4,5],n={};return t.forEach(o=>{n[`
      h${o}&,
      div&-h${o},
      div&-h${o} > textarea,
      h${o}
    `]=gt(e[`fontSizeHeading${o}`],e[`lineHeightHeading${o}`],e.colorTextHeading,e)}),n},mt=e=>{const{componentCls:t}=e;return{"a&, a":f(f({},xe(e)),{textDecoration:e.linkDecoration,"&:active, &:hover":{textDecoration:e.linkHoverDecoration},[`&[disabled], &${t}-disabled`]:{color:e.colorTextDisabled,cursor:"not-allowed","&:active, &:hover":{color:e.colorTextDisabled},"&:active":{pointerEvents:"none"}}})}},bt=()=>({code:{margin:"0 0.2em",paddingInline:"0.4em",paddingBlock:"0.2em 0.1em",fontSize:"85%",background:"rgba(150, 150, 150, 0.1)",border:"1px solid rgba(100, 100, 100, 0.2)",borderRadius:3},kbd:{margin:"0 0.2em",paddingInline:"0.4em",paddingBlock:"0.15em 0.1em",fontSize:"90%",background:"rgba(150, 150, 150, 0.06)",border:"1px solid rgba(100, 100, 100, 0.2)",borderBottomWidth:2,borderRadius:3},mark:{padding:0,backgroundColor:We[2]},"u, ins":{textDecoration:"underline",textDecorationSkipInk:"auto"},"s, del":{textDecoration:"line-through"},strong:{fontWeight:600},"ul, ol":{marginInline:0,marginBlock:"0 1em",padding:0,li:{marginInline:"20px 0",marginBlock:0,paddingInline:"4px 0",paddingBlock:0}},ul:{listStyleType:"circle",ul:{listStyleType:"disc"}},ol:{listStyleType:"decimal"},"pre, blockquote":{margin:"1em 0"},pre:{padding:"0.4em 0.6em",whiteSpace:"pre-wrap",wordWrap:"break-word",background:"rgba(150, 150, 150, 0.1)",border:"1px solid rgba(100, 100, 100, 0.2)",borderRadius:3,code:{display:"inline",margin:0,padding:0,fontSize:"inherit",fontFamily:"inherit",background:"transparent",border:0}},blockquote:{paddingInline:"0.6em 0",paddingBlock:0,borderInlineStart:"4px solid rgba(100, 100, 100, 0.2)",opacity:.85}}),ht=e=>{const{componentCls:t}=e,o=Ue(e).inputPaddingVertical+1;return{"&-edit-content":{position:"relative","div&":{insetInlineStart:-e.paddingSM,marginTop:-o,marginBottom:`calc(1em - ${o}px)`},[`${t}-edit-content-confirm`]:{position:"absolute",insetInlineEnd:e.marginXS+2,insetBlockEnd:e.marginXS,color:e.colorTextDescription,fontWeight:"normal",fontSize:e.fontSize,fontStyle:"normal",pointerEvents:"none"},textarea:{margin:"0!important",MozTransition:"none",height:"1em"}}}},vt=e=>({"&-copy-success":{[`
    &,
    &:hover,
    &:focus`]:{color:e.colorSuccess}}}),Ct=()=>({[`
  a&-ellipsis,
  span&-ellipsis
  `]:{display:"inline-block",maxWidth:"100%"},"&-single-line":{whiteSpace:"nowrap"},"&-ellipsis-single-line":{overflow:"hidden",textOverflow:"ellipsis","a&, span&":{verticalAlign:"bottom"}},"&-ellipsis-multiple-line":{display:"-webkit-box",overflow:"hidden",WebkitLineClamp:3,WebkitBoxOrient:"vertical"}}),xt=e=>{const{componentCls:t,sizeMarginHeadingVerticalStart:n}=e;return{[t]:f(f(f(f(f(f(f(f(f({color:e.colorText,wordBreak:"break-word",lineHeight:e.lineHeight,[`&${t}-secondary`]:{color:e.colorTextDescription},[`&${t}-success`]:{color:e.colorSuccess},[`&${t}-warning`]:{color:e.colorWarning},[`&${t}-danger`]:{color:e.colorError,"a&:active, a&:focus":{color:e.colorErrorActive},"a&:hover":{color:e.colorErrorHover}},[`&${t}-disabled`]:{color:e.colorTextDisabled,cursor:"not-allowed",userSelect:"none"},[`
        div&,
        p
      `]:{marginBottom:"1em"}},yt(e)),{[`
      & + h1${t},
      & + h2${t},
      & + h3${t},
      & + h4${t},
      & + h5${t}
      `]:{marginTop:n},[`
      div,
      ul,
      li,
      p,
      h1,
      h2,
      h3,
      h4,
      h5`]:{[`
        + h1,
        + h2,
        + h3,
        + h4,
        + h5
        `]:{marginTop:n}}}),bt()),mt(e)),{[`
        ${t}-expand,
        ${t}-edit,
        ${t}-copy
      `]:f(f({},xe(e)),{marginInlineStart:e.marginXXS})}),ht(e)),vt(e)),Ct()),{"&-rtl":{direction:"rtl"}})}},Ie=Ve("Typography",e=>[xt(e)],{sizeMarginHeadingVerticalStart:"1.2em",sizeMarginHeadingVerticalEnd:"0.5em"}),St=()=>({prefixCls:String,value:String,maxlength:Number,autoSize:{type:[Boolean,Object]},onSave:Function,onCancel:Function,onEnd:Function,onChange:Function,originContent:String,direction:String,component:String}),Ot=re({compatConfig:{MODE:3},name:"Editable",inheritAttrs:!1,props:St(),setup(e,t){let{emit:n,slots:o,attrs:i}=t;const{prefixCls:c}=Fe(e),a=Se({current:e.value||"",lastKeyCode:void 0,inComposition:!1,cancelFlag:!1});ne(()=>e.value,g=>{a.current=g});const l=oe();Oe(()=>{var g;if(l.value){const d=(g=l.value)===null||g===void 0?void 0:g.resizableTextArea,b=d==null?void 0:d.textArea;b.focus();const{length:m}=b.value;b.setSelectionRange(m,m)}});function h(g){l.value=g}function x(g){let{target:{value:d}}=g;a.current=d.replace(/[\r\n]/g,""),n("change",a.current)}function y(){a.inComposition=!0}function w(){a.inComposition=!1}function N(g){const{keyCode:d}=g;d===Q.ENTER&&g.preventDefault(),!a.inComposition&&(a.lastKeyCode=d)}function T(g){const{keyCode:d,ctrlKey:b,altKey:m,metaKey:O,shiftKey:A}=g;a.lastKeyCode===d&&!a.inComposition&&!b&&!m&&!O&&!A&&(d===Q.ENTER?($(),n("end")):d===Q.ESC&&(a.current=e.originContent,n("cancel")))}function _(){$()}function $(){n("save",a.current.trim())}const[M,B]=Ie(c);return()=>{const g=Ee({[`${c.value}`]:!0,[`${c.value}-edit-content`]:!0,[`${c.value}-rtl`]:e.direction==="rtl",[e.component?`${c.value}-${e.component}`:""]:!0},i.class,B.value);return M(p("div",U(U({},i),{},{class:g}),[p(Ke,{ref:h,maxlength:e.maxlength,value:a.current,onChange:x,onKeydown:N,onKeyup:T,onCompositionstart:y,onCompositionend:w,onBlur:_,rows:1,autoSize:e.autoSize===void 0||e.autoSize},null),o.enterIcon?o.enterIcon({className:`${e.prefixCls}-edit-content-confirm`}):p(ft,{class:`${e.prefixCls}-edit-content-confirm`},null)]))}}}),Et=Ot,Tt=3,wt=8;let S;const te={padding:0,margin:0,display:"inline",lineHeight:"inherit"};function $t(e){return Array.prototype.slice.apply(e).map(n=>`${n}: ${e.getPropertyValue(n)};`).join("")}function De(e,t){e.setAttribute("aria-hidden","true");const n=window.getComputedStyle(t),o=$t(n);e.setAttribute("style",o),e.style.position="fixed",e.style.left="0",e.style.height="auto",e.style.minHeight="auto",e.style.maxHeight="auto",e.style.paddingTop="0",e.style.paddingBottom="0",e.style.borderTopWidth="0",e.style.borderBottomWidth="0",e.style.top="-999999px",e.style.zIndex="-1000",e.style.textOverflow="clip",e.style.whiteSpace="normal",e.style.webkitLineClamp="none"}function It(e){const t=document.createElement("div");De(t,e),t.appendChild(document.createTextNode("text")),document.body.appendChild(t);const n=t.getBoundingClientRect().height;return document.body.removeChild(t),n}const Dt=(e,t,n,o,i)=>{S||(S=document.createElement("div"),S.setAttribute("aria-hidden","true"),document.body.appendChild(S));const{rows:c,suffix:a=""}=t,l=It(e),h=Math.round(l*c*100)/100;De(S,e);const x=Xe({render(){return p("div",{style:te},[p("span",{style:te},[n,a]),p("span",{style:te},[o])])}});x.mount(S);function y(){return Math.round(S.getBoundingClientRect().height*100)/100-.1<=h}if(y())return x.unmount(),{content:n,text:S.innerHTML,ellipsis:!1};const w=Array.prototype.slice.apply(S.childNodes[0].childNodes[0].cloneNode(!0).childNodes).filter(d=>{let{nodeType:b,data:m}=d;return b!==wt&&m!==""}),N=Array.prototype.slice.apply(S.childNodes[0].childNodes[1].cloneNode(!0).childNodes);x.unmount();const T=[];S.innerHTML="";const _=document.createElement("span");S.appendChild(_);const $=document.createTextNode(i+a);_.appendChild($),N.forEach(d=>{S.appendChild(d)});function M(d){_.insertBefore(d,$)}function B(d,b){let m=arguments.length>2&&arguments[2]!==void 0?arguments[2]:0,O=arguments.length>3&&arguments[3]!==void 0?arguments[3]:b.length,A=arguments.length>4&&arguments[4]!==void 0?arguments[4]:0;const H=Math.floor((m+O)/2),G=b.slice(0,H);if(d.textContent=G,m>=O-1)for(let R=O;R>=m;R-=1){const L=b.slice(0,R);if(d.textContent=L,y()||!L)return R===b.length?{finished:!1,vNode:b}:{finished:!0,vNode:L}}return y()?B(d,b,H,O,H):B(d,b,m,H,A)}function g(d){if(d.nodeType===Tt){const m=d.textContent||"",O=document.createTextNode(m);return M(O),B(O,m)}return{finished:!1,vNode:null}}return w.some(d=>{const{finished:b,vNode:m}=g(d);return m&&T.push(m),b}),{content:T,text:S.innerHTML,ellipsis:!0}};var Nt=globalThis&&globalThis.__rest||function(e,t){var n={};for(var o in e)Object.prototype.hasOwnProperty.call(e,o)&&t.indexOf(o)<0&&(n[o]=e[o]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var i=0,o=Object.getOwnPropertySymbols(e);i<o.length;i++)t.indexOf(o[i])<0&&Object.prototype.propertyIsEnumerable.call(e,o[i])&&(n[o[i]]=e[o[i]]);return n};const _t=()=>({prefixCls:String,direction:String,component:String}),Bt=re({name:"ATypography",inheritAttrs:!1,props:_t(),setup(e,t){let{slots:n,attrs:o}=t;const{prefixCls:i,direction:c}=Te("typography",e),[a,l]=Ie(i);return()=>{var h;const x=f(f({},e),o),{prefixCls:y,direction:w,component:N="article"}=x,T=Nt(x,["prefixCls","direction","component"]);return a(p(N,U(U({},T),{},{class:Ee(i.value,{[`${i.value}-rtl`]:c.value==="rtl"},o.class,l.value)}),{default:()=>[(h=n.default)===null||h===void 0?void 0:h.call(n)]}))}}}),Pt=Bt,At=()=>{const e=document.getSelection();if(!e.rangeCount)return function(){};let t=document.activeElement;const n=[];for(let o=0;o<e.rangeCount;o++)n.push(e.getRangeAt(o));switch(t.tagName.toUpperCase()){case"INPUT":case"TEXTAREA":t.blur();break;default:t=null;break}return e.removeAllRanges(),function(){e.type==="Caret"&&e.removeAllRanges(),e.rangeCount||n.forEach(function(o){e.addRange(o)}),t&&t.focus()}},Ht=At,ve={"text/plain":"Text","text/html":"Url",default:"Text"},Rt="Copy to clipboard: #{key}, Enter";function jt(e){const t=(/mac os x/i.test(navigator.userAgent)?"\u2318":"Ctrl")+"+C";return e.replace(/#{\s*key\s*}/g,t)}function zt(e,t){let n,o,i,c,a,l=!1;t||(t={});const h=t.debug||!1;try{if(o=Ht(),i=document.createRange(),c=document.getSelection(),a=document.createElement("span"),a.textContent=e,a.style.all="unset",a.style.position="fixed",a.style.top=0,a.style.clip="rect(0, 0, 0, 0)",a.style.whiteSpace="pre",a.style.webkitUserSelect="text",a.style.MozUserSelect="text",a.style.msUserSelect="text",a.style.userSelect="text",a.addEventListener("copy",function(y){if(y.stopPropagation(),t.format)if(y.preventDefault(),typeof y.clipboardData>"u"){h&&console.warn("unable to use e.clipboardData"),h&&console.warn("trying IE specific stuff"),window.clipboardData.clearData();const w=ve[t.format]||ve.default;window.clipboardData.setData(w,e)}else y.clipboardData.clearData(),y.clipboardData.setData(t.format,e);t.onCopy&&(y.preventDefault(),t.onCopy(y.clipboardData))}),document.body.appendChild(a),i.selectNodeContents(a),c.addRange(i),!document.execCommand("copy"))throw new Error("copy command was unsuccessful");l=!0}catch(x){h&&console.error("unable to copy using execCommand: ",x),h&&console.warn("trying IE specific stuff");try{window.clipboardData.setData(t.format||"text",e),t.onCopy&&t.onCopy(window.clipboardData),l=!0}catch(y){h&&console.error("unable to copy using clipboardData: ",y),h&&console.error("falling back to prompt"),n=jt("message"in t?t.message:Rt),window.prompt(n,e)}}finally{c&&(typeof c.removeRange=="function"?c.removeRange(i):c.removeAllRanges()),a&&document.body.removeChild(a),o()}return l}var kt=globalThis&&globalThis.__rest||function(e,t){var n={};for(var o in e)Object.prototype.hasOwnProperty.call(e,o)&&t.indexOf(o)<0&&(n[o]=e[o]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var i=0,o=Object.getOwnPropertySymbols(e);i<o.length;i++)t.indexOf(o[i])<0&&Object.prototype.propertyIsEnumerable.call(e,o[i])&&(n[o[i]]=e[o[i]]);return n};const Mt=we("webkitLineClamp"),Lt=we("textOverflow"),Ce="...",Ne=()=>({editable:{type:[Boolean,Object],default:void 0},copyable:{type:[Boolean,Object],default:void 0},prefixCls:String,component:String,type:String,disabled:{type:Boolean,default:void 0},ellipsis:{type:[Boolean,Object],default:void 0},code:{type:Boolean,default:void 0},mark:{type:Boolean,default:void 0},underline:{type:Boolean,default:void 0},delete:{type:Boolean,default:void 0},strong:{type:Boolean,default:void 0},keyboard:{type:Boolean,default:void 0},content:String,"onUpdate:content":Function}),Wt=re({compatConfig:{MODE:3},name:"Base",inheritAttrs:!1,props:Ne(),setup(e,t){let{slots:n,attrs:o,emit:i}=t;const{prefixCls:c,direction:a}=Te("typography",e),l=Se({copied:!1,ellipsisText:"",ellipsisContent:null,isEllipsis:!1,expanded:!1,clientRendered:!1,expandStr:"",copyStr:"",copiedStr:"",editStr:"",copyId:void 0,rafId:void 0,prevProps:void 0,originContent:""}),h=oe(),x=oe(),y=X(()=>{const r=e.ellipsis;return r?f({rows:1,expandable:!1},typeof r=="object"?r:null):{}});Oe(()=>{l.clientRendered=!0}),qe(()=>{clearTimeout(l.copyId),Y.cancel(l.rafId)}),ne([()=>y.value.rows,()=>e.content],()=>{fe(()=>{O()})},{flush:"post",deep:!0,immediate:!0}),Ge(()=>{e.content===void 0&&(ie(!e.editable),ie(!e.ellipsis))});function w(){var r;return e.ellipsis||e.editable?e.content:(r=Z(h.value))===null||r===void 0?void 0:r.innerText}function N(r){const{onExpand:s}=y.value;l.expanded=!0,s==null||s(r)}function T(r){r.preventDefault(),l.originContent=e.content,m(!0)}function _(r){$(r),m(!1)}function $(r){const{onChange:s}=g.value;r!==e.content&&(i("update:content",r),s==null||s(r))}function M(){var r,s;(s=(r=g.value).onCancel)===null||s===void 0||s.call(r),m(!1)}function B(r){r.preventDefault(),r.stopPropagation();const{copyable:s}=e,u=f({},typeof s=="object"?s:null);u.text===void 0&&(u.text=w()),zt(u.text||""),l.copied=!0,fe(()=>{u.onCopy&&u.onCopy(r),l.copyId=setTimeout(()=>{l.copied=!1},3e3)})}const g=X(()=>{const r=e.editable;return r?f({},typeof r=="object"?r:null):{editing:!1}}),[d,b]=Je(!1,{value:X(()=>g.value.editing)});function m(r){const{onStart:s}=g.value;r&&s&&s(),b(r)}ne(d,r=>{var s;r||(s=x.value)===null||s===void 0||s.focus()},{flush:"post"});function O(){Y.cancel(l.rafId),l.rafId=Y(()=>{H()})}const A=X(()=>{const{rows:r,expandable:s,suffix:u,onEllipsis:v,tooltip:C}=y.value;return u||C||e.editable||e.copyable||s||v?!1:r===1?Lt:Mt}),H=()=>{const{ellipsisText:r,isEllipsis:s}=l,{rows:u,suffix:v,onEllipsis:C}=y.value;if(!u||u<0||!Z(h.value)||l.expanded||e.content===void 0||A.value)return;const{content:I,text:j,ellipsis:P}=Dt(Z(h.value),{rows:u,suffix:v},e.content,de(!0),Ce);(r!==j||l.isEllipsis!==P)&&(l.ellipsisText=j,l.ellipsisContent=I,l.isEllipsis=P,s!==P&&C&&C(P))};function G(r,s){let{mark:u,code:v,underline:C,delete:I,strong:j,keyboard:P}=r,W=s;function D(V,E){if(!V)return;const F=function(){return W}();W=p(E,null,{default:()=>[F]})}return D(j,"strong"),D(C,"u"),D(I,"del"),D(v,"code"),D(u,"mark"),D(P,"kbd"),W}function R(r){const{expandable:s,symbol:u}=y.value;if(!s||!r&&(l.expanded||!l.isEllipsis))return null;const v=(n.ellipsisSymbol?n.ellipsisSymbol():u)||l.expandStr;return p("a",{key:"expand",class:`${c.value}-expand`,onClick:N,"aria-label":l.expandStr},[v])}function L(){if(!e.editable)return;const{tooltip:r,triggerType:s=["icon"]}=e.editable,u=n.editableIcon?n.editableIcon():p(ct,{role:"button"},null),v=n.editableTooltip?n.editableTooltip():l.editStr,C=typeof v=="string"?v:"";return s.indexOf("icon")!==-1?p(ee,{key:"edit",title:r===!1?"":v},{default:()=>[p(ye,{ref:x,class:`${c.value}-edit`,onClick:T,"aria-label":C},{default:()=>[u]})]}):null}function _e(){if(!e.copyable)return;const{tooltip:r}=e.copyable,s=l.copied?l.copiedStr:l.copyStr,u=n.copyableTooltip?n.copyableTooltip({copied:l.copied}):s,v=typeof u=="string"?u:"",C=l.copied?p(et,null,null):p(lt,null,null),I=n.copyableIcon?n.copyableIcon({copied:!!l.copied}):C;return p(ee,{key:"copy",title:r===!1?"":u},{default:()=>[p(ye,{class:[`${c.value}-copy`,{[`${c.value}-copy-success`]:l.copied}],onClick:B,"aria-label":v},{default:()=>[I]})]})}function Be(){const{class:r,style:s}=o,{maxlength:u,autoSize:v,onEnd:C}=g.value;return p(Et,{class:r,style:s,prefixCls:c.value,value:e.content,originContent:l.originContent,maxlength:u,autoSize:v,onSave:_,onChange:$,onCancel:M,onEnd:C,direction:a.value,component:e.component},{enterIcon:n.editableEnterIcon})}function de(r){return[R(r),L(),_e()].filter(s=>s)}return()=>{var r;const{triggerType:s=["icon"]}=g.value,u=e.ellipsis||e.editable?e.content!==void 0?e.content:(r=n.default)===null||r===void 0?void 0:r.call(n):n.default?n.default():e.content;return d.value?Be():p(Ze,{componentName:"Text",children:v=>{const C=f(f({},e),o),{type:I,disabled:j,content:P,class:W,style:D}=C,V=kt(C,["type","disabled","content","class","style"]),{rows:E,suffix:F,tooltip:J}=y.value,{edit:Pe,copy:Ae,copied:He,expand:Re}=v;l.editStr=Pe,l.copyStr=Ae,l.copiedStr=He,l.expandStr=Re;const je=$e(V,["prefixCls","editable","copyable","ellipsis","mark","code","delete","underline","strong","keyboard","onUpdate:content"]),K=A.value,ze=E===1&&K,ue=E&&E>1&&K;let z=u,ke;if(E&&l.isEllipsis&&!l.expanded&&!K){const{title:pe}=V;let k=pe||"";!pe&&(typeof u=="string"||typeof u=="number")&&(k=String(u)),k=k==null?void 0:k.slice(String(l.ellipsisContent||"").length),z=p(ge,null,[Qe(l.ellipsisContent),p("span",{title:k,"aria-hidden":"true"},[Ce]),F])}else z=p(ge,null,[u,F]);z=G(e,z);const Me=J&&E&&l.isEllipsis&&!l.expanded&&!K,Le=n.ellipsisTooltip?n.ellipsisTooltip():J;return p(Ye,{onResize:O,disabled:!E},{default:()=>[p(Pt,U({ref:h,class:[{[`${c.value}-${I}`]:I,[`${c.value}-disabled`]:j,[`${c.value}-ellipsis`]:E,[`${c.value}-single-line`]:E===1&&!l.isEllipsis,[`${c.value}-ellipsis-single-line`]:ze,[`${c.value}-ellipsis-multiple-line`]:ue},W],style:f(f({},D),{WebkitLineClamp:ue?E:void 0}),"aria-label":ke,direction:a.value,onClick:s.indexOf("text")!==-1?T:()=>{}},je),{default:()=>[Me?p(ee,{title:J===!0?u:Le},{default:()=>[p("span",null,[z])]}):z,de()]})]})}},null)}}}),Ut=Wt;var Vt=globalThis&&globalThis.__rest||function(e,t){var n={};for(var o in e)Object.prototype.hasOwnProperty.call(e,o)&&t.indexOf(o)<0&&(n[o]=e[o]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var i=0,o=Object.getOwnPropertySymbols(e);i<o.length;i++)t.indexOf(o[i])<0&&Object.prototype.propertyIsEnumerable.call(e,o[i])&&(n[o[i]]=e[o[i]]);return n};const Ft=tt(1,2,3,4,5),Kt=()=>f(f({},$e(Ne(),["component","strong"])),{level:Number}),q=(e,t)=>{let{slots:n,attrs:o}=t;const{level:i=1}=e,c=Vt(e,["level"]);let a;Ft.includes(i)?a=`h${i}`:(ie(),a="h1");const l=f(f(f({},c),{component:a}),o);return p(Ut,l,n)};q.displayName="ATypographyTitle";q.inheritAttrs=!1;q.props=Kt();const Gt=q;export{Gt as A,Ut as B,Pt as T,Ne as b};
//# sourceMappingURL=Title.d1f45d59.js.map
