import{B as i,b as f,T as r,A as g}from"./Title.d1f45d59.js";import{U as a,ab as _,f as m,Q as b}from"./registerWidgets.1e9167ab.js";import{A as h}from"./Text.c8d7b4c0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="6c17f48a-27c1-4b09-8273-fe9dde2bb364",e._sentryDebugIdIdentifier="sentry-dbid-6c17f48a-27c1-4b09-8273-fe9dde2bb364")}catch{}})();var A=globalThis&&globalThis.__rest||function(e,o){var s={};for(var t in e)Object.prototype.hasOwnProperty.call(e,t)&&o.indexOf(t)<0&&(s[t]=e[t]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var n=0,t=Object.getOwnPropertySymbols(e);n<t.length;n++)o.indexOf(t[n])<0&&Object.prototype.propertyIsEnumerable.call(e,t[n])&&(s[t[n]]=e[t[n]]);return s};const w=()=>b(a(a({},f()),{ellipsis:{type:Boolean,default:void 0}}),["component"]),p=(e,o)=>{let{slots:s,attrs:t}=o;const n=a(a({},e),t),{ellipsis:P,rel:d}=n,y=A(n,["ellipsis","rel"]);_();const c=a(a({},y),{rel:d===void 0&&y.target==="_blank"?"noopener noreferrer":d,ellipsis:!!P,component:"a"});return delete c.navigate,m(i,c,s)};p.displayName="ATypographyLink";p.inheritAttrs=!1;p.props=w();const u=p,O=()=>b(f(),["component"]),l=(e,o)=>{let{slots:s,attrs:t}=o;const n=a(a(a({},e),{component:"div"}),t);return m(i,n,s)};l.displayName="ATypographyParagraph";l.inheritAttrs=!1;l.props=O();const T=l;r.Text=h;r.Title=g;r.Paragraph=T;r.Link=u;r.Base=i;r.install=function(e){return e.component(r.name,r),e.component(r.Text.displayName,h),e.component(r.Title.displayName,g),e.component(r.Paragraph.displayName,T),e.component(r.Link.displayName,u),e};export{T as A,u as L};
//# sourceMappingURL=index.9165a659.js.map
