import{v as r,a,b as i,c,g as p,h as d,_,i as u,l,T as f,P as h,C as g,M as y,s as m,j as b,k as s,m as v,n as w,p as k}from"./registerWidgets.1e9167ab.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="162fe24e-74cf-4987-bd85-83015c5ccd65",e._sentryDebugIdIdentifier="sentry-dbid-162fe24e-74cf-4987-bd85-83015c5ccd65")}catch{}})();const I={};function A(e,t){const n=a("router-view");return i(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const x=r(I,[["render",A]]),o=p({history:d("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.9fb0f91e.js"),["assets/Player.9fb0f91e.js","assets/index.89742732.js","assets/registerWidgets.1e9167ab.js","assets/registerWidgets.74435dfa.css","assets/uuid.eb101573.js","assets/broker.d4f9d0c3.js","assets/passwordlessManager.b7f590c1.js","assets/pubsub.09eafe35.js","assets/storage.84fcb572.js","assets/Passwordless.a466b928.js","assets/CircularLoading.b699e65c.js","assets/CircularLoading.f81b57b4.css","assets/icons.41af03d8.js","assets/Passwordless.38735f5c.css","assets/executeJs.994915b2.js","assets/PlayerNavbar.399148eb.js","assets/PlayerNavbar.76a7eb2f.css","assets/Steps.64a40e70.js","assets/Steps.998aa76d.css","assets/Modal.b646cd22.js","assets/Modal.5aaf8eba.css","assets/executeJs.887e9a58.css","assets/WidgetsFrame.75884b13.js","assets/WidgetsFrame.0816a5f5.css","assets/ActionButton.vue_vue_type_script_setup_true_lang.2753de3d.js","assets/broker.54a676ec.css","assets/DashPlayer.927cc972.js","assets/geometryUtils.ea06ddf6.js","assets/DashPlayer.4868beea.css","assets/asyncComputed.8a644895.js","assets/Player.77337a17.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}});class D{static init(){setInterval(()=>fetch("/_healthcheck"),20*1e3)}}const W=()=>{const e=u({render:()=>l(x)});f.init(),D.init(),e.use(o),e.use(h),e.mount("#app"),e.component("VSelect",g),e.component("Markdown",y),e.component("Message",m),b(e,o),s(e,v),s(e,w),s(e,k)};W();
//# sourceMappingURL=player.b77d1c2a.js.map
