import{M as a}from"./Modal.b646cd22.js";import{d as r,G as d,r as c,a as _,b as f,er as l,f as n,w as i,bu as u,e as m,v as b}from"./registerWidgets.1e9167ab.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="d280f7a9-3618-4b54-bbb1-3c0310d87aa4",e._sentryDebugIdIdentifier="sentry-dbid-d280f7a9-3618-4b54-bbb1-3c0310d87aa4")}catch{}})();const p=["src"],y=r({__name:"Home",setup(e){const o=d({onboardingForm:""}),t=c(null);return(g,v)=>{const s=_("router-view");return f(),l(u,null,[n(s,{class:"router"}),n(a,{ref_key:"modal",ref:t},{content:i(()=>[m("iframe",{class:"form",src:o.onboardingForm},null,8,p)]),_:1},512)],64)}}});const x=b(y,[["__scopeId","data-v-7e290e34"]]);export{x as default};
//# sourceMappingURL=Home.0c1f10c4.js.map
