import{d as m,ey as d,H as l,b as c,c as u,u as f,v as _}from"./registerWidgets.1e9167ab.js";import{a as y}from"./asyncComputed.8a644895.js";import"./gateway.6096f5a8.js";import{B as b}from"./build.3b111c11.js";import"./index.11f5d4e4.js";import{L as g,N as w}from"./icons.41af03d8.js";import{r as I}from"./console.355f1609.js";import{_ as x}from"./CrudView.vue_vue_type_script_setup_true_lang.e0bf9fc2.js";import{f as v}from"./index.b048d0fb.js";import"./passwordlessManager.b7f590c1.js";import"./pubsub.09eafe35.js";import"./storage.84fcb572.js";import"./activeRecord.60b6bd01.js";import"./index.89742732.js";import"./Form.0a031d70.js";import"./FormItem.7ea68eff.js";import"./transButton.755e702e.js";import"./index.4b30ebdc.js";import"./index.d74062f4.js";import"./index.ed4213c8.js";import"./index.8a092bed.js";import"./dayjs.3081011a.js";import"./index.ff683f30.js";import"./index.d8a9ea06.js";import"./index.b4361545.js";import"./index.b87a5de2.js";import"./index.7ad61a34.js";import"./index.32c7f8ee.js";import"./index.629b1b19.js";import"./index.9165a659.js";import"./Title.d1f45d59.js";import"./Text.c8d7b4c0.js";import"./Modal.b646cd22.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="0f409530-236e-46c3-b953-83ddb7fd8091",o._sentryDebugIdIdentifier="sentry-dbid-0f409530-236e-46c3-b953-83ddb7fd8091")}catch{}})();const B=m({__name:"Builds",setup(o){const r=d().params.projectId,{loading:s,result:n}=y(()=>b.list(r)),p=l(()=>{var i,a;return{columns:[{name:"Id"},{name:"Date"},{name:"Status"},{name:"Actions"}],rows:(a=(i=n.value)==null?void 0:i.map(t=>({key:t.id,cells:[{text:t.id.slice(0,8)},{text:v(t.createdAt,Date.now(),{addSuffix:!0})},{text:t.status+(t.log?": "+t.log:"")},{text:"",actions:[{icon:g,label:"View logs",onClick:()=>I.push({name:"logs",params:{projectId:r},query:{buildId:t.id}})},{icon:w,label:"Download files",onClick:()=>t.download()}]}]})))!=null?a:[]}});return(i,a)=>(c(),u(x,{"entity-name":"build",loading:f(s),title:"Builds",description:"Each build is a version of your app. You can create a new build by deploying your app from the local editor.","empty-title":"No builds here yet",table:p.value},null,8,["loading","table"]))}});const rt=_(B,[["__scopeId","data-v-03f70823"]]);export{rt as default};
//# sourceMappingURL=Builds.011e2882.js.map
