import{d as i,r as l,o as d,eO as c,b as f,er as u,eA as b,eM as p}from"./registerWidgets.1e9167ab.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="1eb16bcb-eaf2-4a63-aec6-3302024e2878",e._sentryDebugIdIdentifier="sentry-dbid-1eb16bcb-eaf2-4a63-aec6-3302024e2878")}catch{}})();const m=i({__name:"ActionButton",props:{action:{},displayName:{}},emits:["click"],setup(e,{emit:n}){const o=e,s=l(null);return d(()=>{s.value&&o.action.setElement(s.value),c.addAction(o.action)}),(a,t)=>(f(),u("button",{ref_key:"element",ref:s,class:"next-button",onClick:t[0]||(t[0]=r=>n("click")),onKeydown:t[1]||(t[1]=p(r=>n("click"),["enter"]))},b(a.displayName),545))}});export{m as _};
//# sourceMappingURL=ActionButton.vue_vue_type_script_setup_true_lang.2753de3d.js.map
