import{d as _,ey as b,ex as w,H as g,b as n,er as D,u,c as p,eu as d,bu as k,v as P}from"./registerWidgets.1e9167ab.js";import{D as I,m as x}from"./DashPlayer.927cc972.js";import{L as B}from"./CircularLoading.b699e65c.js";import{r as R}from"./index.89742732.js";import{B as q}from"./BackButton.eea183ae.js";import{a as l}from"./asyncComputed.8a644895.js";import{D as C}from"./dashes.6c2a613d.js";import{W as E}from"./workspaces.681666ae.js";import"./executeJs.994915b2.js";import"./PlayerNavbar.399148eb.js";import"./icons.41af03d8.js";import"./Steps.64a40e70.js";import"./Modal.b646cd22.js";import"./geometryUtils.ea06ddf6.js";import"./passwordlessManager.b7f590c1.js";import"./pubsub.09eafe35.js";import"./storage.84fcb572.js";import"./Passwordless.a466b928.js";import"./WidgetsFrame.75884b13.js";import"./activeRecord.60b6bd01.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[r]="876ecfba-e954-4100-8f5c-e28aaadbbbac",t._sentryDebugIdIdentifier="sentry-dbid-876ecfba-e954-4100-8f5c-e28aaadbbbac")}catch{}})();const F=_({__name:"DashPreview",setup(t){const r=b(),s=w(),m=({id:e,type:o})=>{o==="dash"?(s.push({name:"dashPreview",params:{dashId:e},query:r.query}),y()):s.push({name:"formPreview",params:{formId:e},query:r.query})},f=()=>{var e;!((e=a.value)!=null&&e.path)||s.push(`/_editor/dash/${encodeURIComponent(a.value.path)}`)},{loading:v,result:a,refetch:y}=l(()=>C.get(r.params.dashPath)),{result:i}=l(()=>E.get()),c=g(()=>{if(!a.value||!i.value||!a.value.makeRunnerData(i.value))return null;const e=x(a.value.makeRunnerData(i.value));return e.onRedirect(({url:o,queryParams:h})=>R("preview",s,o,h)),e});return(e,o)=>(n(),D(k,null,[u(v)||!u(a)?(n(),p(B,{key:0,class:"loading",justify:"center"})):d("",!0),c.value?(n(),p(I,{key:1,class:"player",dash:c.value.runnerData,"widgets-with-errors":[],"is-preview":!0,params:u(r).query,"dash-player-service":c.value,onNavigate:m},null,8,["dash","params","dash-player-service"])):d("",!0),u(a)?(n(),p(q,{key:2,onExitFullscreenPreview:f})):d("",!0)],64))}});const Z=P(F,[["__scopeId","data-v-1172cf43"]]);export{Z as default};
//# sourceMappingURL=DashPreview.7006482a.js.map
