import{d as g,ex as v,ey as b,r as k,b as r,c as a,w as s,u as e,f as l,eu as i}from"./registerWidgets.1e9167ab.js";import{S as h,L as w}from"./SmartConsole.035658a5.js";import{a as x}from"./asyncComputed.8a644895.js";import{H as B}from"./hooks.9dbb5925.js";import{_ as C}from"./SaveButton.vue_vue_type_script_setup_true_lang.77a4e1fa.js";import{_ as H}from"./DocsButton.vue_vue_type_script_setup_true_lang.5ae278fd.js";import{B as I}from"./BaseLayout.6055d322.js";import{_ as S,a as T}from"./HookSettings.vue_vue_type_script_setup_true_lang.b77b8213.js";import{c as D}from"./index.4b30ebdc.js";import{a as _,T as R}from"./index.b4361545.js";import"./forms.5cb504dd.js";import"./activeRecord.60b6bd01.js";import"./pubsub.09eafe35.js";import"./dashes.6c2a613d.js";import"./index.89742732.js";import"./jobs.10e8045a.js";import"./workspaces.681666ae.js";import"./icons.41af03d8.js";import"./Title.d1f45d59.js";import"./transButton.755e702e.js";import"./FormItem.7ea68eff.js";import"./uuid.eb101573.js";import"./storage.84fcb572.js";import"./index.ff683f30.js";import"./index.7ad61a34.js";import"./index.d74062f4.js";import"./index.32c7f8ee.js";import"./Form.0a031d70.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},m=new Error().stack;m&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[m]="5e67769c-e174-4818-a8a2-6fdc0d6682f2",n._sentryDebugIdIdentifier="sentry-dbid-5e67769c-e174-4818-a8a2-6fdc0d6682f2")}catch{}})();const ie=g({__name:"HookEditor",setup(n){const m=v(),c=b(),p=k(null),o=k("test");function y(){m.push({name:"hooks"})}const{result:t}=x(()=>B.get(c.params.hookPath)),f=w.create();return($,d)=>(r(),a(I,null,{navbar:s(()=>[e(t)?(r(),a(e(D),{key:0,title:e(t).title,onBack:y},{footer:s(()=>[l(e(R),{"active-key":o.value,"onUpdate:activeKey":d[0]||(d[0]=u=>o.value=u)},{default:s(()=>[l(e(_),{key:"test",tab:"Test"}),l(e(_),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:s(()=>[l(H,{path:"hooks"}),o.value==="settings"?(r(),a(C,{key:0,model:e(t)},null,8,["model"])):i("",!0)]),_:1},8,["title"])):i("",!0)]),content:s(()=>[e(t)&&o.value==="test"?(r(),a(S,{key:0,ref_key:"tester",ref:p,hook:e(t),"log-service":e(f)},null,8,["hook","log-service"])):i("",!0),e(t)&&o.value==="settings"?(r(),a(T,{key:1,hook:e(t)},null,8,["hook"])):i("",!0)]),footer:s(()=>{var u;return[e(t)&&o.value==="test"?(r(),a(h,{key:0,runtime:"forms","log-service":e(f),onRestart:(u=p.value)==null?void 0:u.runHook},null,8,["log-service","onRestart"])):i("",!0)]}),_:1}))}});export{ie as default};
//# sourceMappingURL=HookEditor.831af7bd.js.map
