import{v as t,b as d,er as s}from"./registerWidgets.1e9167ab.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="a5d9d2d4-24d5-4784-beda-73a0e1a3fe84",e._sentryDebugIdIdentifier="sentry-dbid-a5d9d2d4-24d5-4784-beda-73a0e1a3fe84")}catch{}})();const a={},r={class:"organization-settings"};function o(e,n){return d(),s("div",r,"Organization settings")}const f=t(a,[["render",o]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.805e5921.js.map
