import{P as r}from"./Passwordless.a466b928.js";import{d as a,ex as d,b as i,er as f,f as s,w as _,v as c}from"./registerWidgets.1e9167ab.js";import{M as m}from"./member.7cd65334.js";import{W as p}from"./WidgetsFrame.75884b13.js";import"./CircularLoading.b699e65c.js";import"./icons.41af03d8.js";import"./passwordlessManager.b7f590c1.js";import"./pubsub.09eafe35.js";import"./storage.84fcb572.js";import"./gateway.6096f5a8.js";import"./activeRecord.60b6bd01.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="0d49884a-8e62-4dfd-9da2-d3560f7af74e",e._sentryDebugIdIdentifier="sentry-dbid-0d49884a-8e62-4dfd-9da2-d3560f7af74e")}catch{}})();const l={class:"login"},u=a({__name:"Login",setup(e){const o=d();async function t(n){await m.login(),o.push({name:"home"})}return(n,g)=>(i(),f("div",l,[s(p,{theme:"white","main-color":"#d14056","font-family":"sans-serif",runtime:"dash"},{default:_(()=>[s(r,{class:"passwordless",onDone:t})]),_:1})]))}});const B=c(u,[["__scopeId","data-v-0e3dc783"]]);export{B as default};
//# sourceMappingURL=Login.5579aa18.js.map
