import{d as u,ey as g,H as m,a as b,b as f,c as v,w as i,f as s}from"./registerWidgets.1e9167ab.js";import{B as _}from"./BaseLayout.6055d322.js";import{a as y}from"./asyncComputed.8a644895.js";import{P as h}from"./project.9f45bccb.js";import"./gateway.6096f5a8.js";import{O as z}from"./organization.a2c74ee1.js";import"./index.11f5d4e4.js";import{_ as j}from"./Navbar.vue_vue_type_script_setup_true_lang.901e5473.js";import{S as I}from"./Sidebar.47ce3a0b.js";import{G as w,H as k,I as B,J as P,K as $,L as C,M as D,D as M,E as x,F as L}from"./icons.41af03d8.js";import"./activeRecord.60b6bd01.js";import"./pubsub.09eafe35.js";import"./passwordlessManager.b7f590c1.js";import"./storage.84fcb572.js";import"./logo.084e5d7c.js";import"./Text.c8d7b4c0.js";import"./Title.d1f45d59.js";import"./transButton.755e702e.js";import"./index.d74062f4.js";import"./index.4b30ebdc.js";import"./Tooltip.4e859285.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="4014266d-a4da-4e78-9a95-d8f81c878efd",o._sentryDebugIdIdentifier="sentry-dbid-4014266d-a4da-4e78-9a95-d8f81c878efd")}catch{}})();const ea=u({__name:"Project",setup(o){const c=g().params.projectId,{result:a}=y(()=>h.get(c).then(async e=>{const t=await z.get(e.organizationId);return{project:e,organization:t}})),l=m(()=>{var e,t,n,p;return((e=a.value)==null?void 0:e.organization)&&a.value.project?[{label:"My organizations",path:"/organizations"},{label:(n=(t=a.value)==null?void 0:t.organization)==null?void 0:n.name,path:`/organizations/${(p=a.value)==null?void 0:p.organization.id}`},{label:a.value.project.name,path:`/projects/${a.value.project.id}`}]:void 0}),d=m(()=>{var e;return(e=a.value)!=null&&e.project?[{name:"Project",items:[{name:"Builds",path:"builds",icon:w},{name:"Connectors",path:"connectors",icon:k},{name:"Tables",path:"tables",icon:B},{name:"API Keys",path:"api-keys",icon:P},{name:"Env Vars",path:"env-vars",icon:$},{name:"Logs",icon:C,path:"logs",beta:!0},{name:"Settings",icon:D,path:"settings"}]},{name:"Organization",items:[{name:"Projects",icon:M,path:`/organizations/${a.value.project.organizationId}/projects`},{name:"Members",icon:x,path:`/organizations/${a.value.project.organizationId}/members`},{name:"Billing",icon:L,path:`/organizations/${a.value.project.organizationId}/billing`,unavailable:!0}]}]:[]});return(e,t)=>{const n=b("router-view");return f(),v(_,null,{content:i(()=>[s(n)]),navbar:i(()=>[s(j,{class:"nav",breadcrumb:l.value},null,8,["breadcrumb"])]),sidebar:i(()=>[s(I,{class:"sidebar",sections:d.value},null,8,["sections"])]),_:1})}}});export{ea as default};
//# sourceMappingURL=Project.c0444a64.js.map
