import{S as p}from"./Sidebar.47ce3a0b.js";import{_ as c}from"./Navbar.vue_vue_type_script_setup_true_lang.901e5473.js";import{D as d,E as l,F as u}from"./icons.41af03d8.js";import{d as b,ey as f,H as g,a as _,b as y,c as v,w as t,f as r}from"./registerWidgets.1e9167ab.js";import{a as w}from"./asyncComputed.8a644895.js";import"./gateway.6096f5a8.js";import{O as z}from"./organization.a2c74ee1.js";import"./index.11f5d4e4.js";import{B as h}from"./BaseLayout.6055d322.js";import"./Tooltip.4e859285.js";import"./logo.084e5d7c.js";import"./passwordlessManager.b7f590c1.js";import"./pubsub.09eafe35.js";import"./storage.84fcb572.js";import"./Text.c8d7b4c0.js";import"./Title.d1f45d59.js";import"./transButton.755e702e.js";import"./index.d74062f4.js";import"./index.4b30ebdc.js";import"./activeRecord.60b6bd01.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="91da53aa-95a5-445e-bb29-8ef780f296dc",a._sentryDebugIdIdentifier="sentry-dbid-91da53aa-95a5-445e-bb29-8ef780f296dc")}catch{}})();const J=b({__name:"Organization",setup(a){const n=f().params.organizationId,{result:o}=w(()=>z.get(n)),i=g(()=>o.value?[{label:"My organizations",path:"/organizations"},{label:o.value.name,path:`/organizations/${o.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing",unavailable:!0}]}];return(I,B)=>{const m=_("router-view");return y(),v(h,null,{navbar:t(()=>[r(c,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:t(()=>[r(p,{class:"sidebar",sections:s})]),content:t(()=>[r(m)]),_:1})}}});export{J as default};
//# sourceMappingURL=Organization.ea41f603.js.map
