import{d as u,ey as f,H as b,b as y,c as _,u as g}from"./registerWidgets.1e9167ab.js";import{a as w}from"./asyncComputed.8a644895.js";import"./gateway.6096f5a8.js";import{M as n}from"./member.7cd65334.js";import"./index.11f5d4e4.js";import{_ as I}from"./CrudView.vue_vue_type_script_setup_true_lang.e0bf9fc2.js";import"./passwordlessManager.b7f590c1.js";import"./pubsub.09eafe35.js";import"./storage.84fcb572.js";import"./activeRecord.60b6bd01.js";import"./Modal.b646cd22.js";import"./Title.d1f45d59.js";import"./transButton.755e702e.js";import"./index.9165a659.js";import"./Text.c8d7b4c0.js";import"./index.32c7f8ee.js";import"./index.d74062f4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="8d9e7a3c-c64d-497d-8d7d-01654f887b52",e._sentryDebugIdIdentifier="sentry-dbid-8d9e7a3c-c64d-497d-8d7d-01654f887b52")}catch{}})();const j=u({__name:"Members",setup(e){const a=f().params.organizationId,m=[{key:"email",label:"Email"}],s=async t=>{await n.create(a,t.email),c()},{loading:d,result:l,refetch:c}=w(()=>n.list(a)),p=b(()=>{var t,r;return{columns:[{name:"Email"},{name:"Role"}],rows:(r=(t=l.value)==null?void 0:t.map(i=>({key:i.email,cells:[{text:i.email},{text:i.role}]})))!=null?r:[]}});return(t,r)=>(y(),_(I,{"entity-name":"members",loading:g(d),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:p.value,"create-button-text":"Add members",fields:m,onCreate:s},null,8,["loading","table"]))}});export{j as default};
//# sourceMappingURL=Members.dcab5cd8.js.map
